Changelog
=========


(unreleased)
------------
- Last before bumpversion. [Toni]
- Add universal binaries. [Toni G]
- Update cibuildwheel (#10) [Toni G]

  * Update build.yml

  * Update build.yml
- Roxygen works again, revamped docs. [Toni]
- New maint code. [Toni]
- Note on abandoning autogen. [Toni]
- Merge from R. [Toni]


v1.1.6 (2020-09-25)
-------------------
- Last before bumpversion. [Toni]
- Merged with R. [Toni]


v1.1.5 (2020-06-22)
-------------------
- Remove runtime dep on setuptools. [Toni]
- Badges. [Toni]
- Codecov. [Toni]
- Codecov. [Toni]
- Codecov. [Toni]
- Codecov. [Toni]
- Changelog. [Toni]


v1.1.4 (2020-06-19)
-------------------
- Add callable main. cleanups. [Toni]


v1.1.3 (2020-06-18)
-------------------
- Doctests again. [Toni]


v1.1.2 (2020-06-18)
-------------------
- Ci doctests. [Toni]


v1.1.1 (2020-06-18)
-------------------
- Doctests. [Toni]
- Improve warp and docs. [Toni]


v1.1.0 (2020-06-18)
-------------------
- Before bump. [Toni]
- Dont cythonize in build. [Toni]
- Test deployer. [Toni]
- Python version. [Toni]
- Absolute imports. [Toni]

  abs imports
- Test setup requires. [Toni]
- Test cibuildwheel. [Toni]
- Added test for issue https://github.com/DynamicTimeWarping/dtw-
  python/issues/5. [Toni]


v1.0.6 (2020-06-17)
-------------------
- Fixed subtle bug with open_begin. [Toni]
- Adding CRAN test equivalent. [Toni]
- Fixes https://github.com/DynamicTimeWarping/dtw-python/issues/5.
  [Toni]


v1.0.5 (2020-02-24)
-------------------
- Fix for open-end with slope-constrained alignments. [Toni]
- Merge pull request #3 from tcwalther/fix-slantedbandwindow. [Toni G]

  fix slantedBandWindow function - thanks!
- Fix slantedBandWindow function. [Thomas Walther]

  The previous version had variable names such as query.size in it
   - notation which is common in R, but doesn't work in Python.
   This commit corrects these names to query_size, reference_size
   and window_size, respectively.


v1.0.4 (2019-12-30)
-------------------
- Fixes https://github.com/DynamicTimeWarping/dtw-python/issues/1.
  [Toni]
- Possible fix for windows. [Toni]
- Conda env. [Toni]


v1.0.2 (2019-09-04)
-------------------
- Minor fixes. [Toni]
- Aami doctests maybe. [Toni]


v1.0.1 (2019-09-01)
-------------------
- Last before bumpversion. [Toni]
- Misc bugs. [Toni]


v0.5.2 (2019-08-31)
-------------------
- Last before bumpversion. [Toni]


v0.5.1 (2019-08-31)
-------------------
- Last before bumpversion. [Toni]


v0.5.0 (2019-08-31)
-------------------
- Docs index. [Toni]
- Fixup docs. [Toni]
- Automodapi. [Toni]
- Using bootstrap theme. [Toni]


v0.4.0 (2019-08-30)
-------------------
- Renames. [Toni]
- Rename. [Toni]


v0.3.10 (2019-08-30)
--------------------
- Make release. [Toni]


v0.3.9 (2019-08-30)
-------------------
- Make release. [Toni]


v0.3.7 (2019-08-30)
-------------------
- Setup. [Toni]


v0.3.6 (2019-08-30)
-------------------
- Return axes plot. [Toni]


v0.3.0 (2019-08-29)
-------------------
- C file. [Toni]


v0.2.0 (2019-08-29)
-------------------
- Doctests. [Toni]
- Dtw doc. [Toni]
- Squash spaces. [Toni]
- Tests. [Toni]
- Rename. [Toni]
- Progress. [Toni]
- Going for tests. [Toni]
- Checkpoint. [Toni]
- Testing examples. [Toni]
- New docs. [Toni]
- Hide _get_p. [Toni]
- Entry point. [Toni]
- Remove dependency on click. [Toni]
- Tests. [Toni]
- Test cli. [Toni]
- Cli ok. [Toni]
- Attempt at reformat. [Toni]
- Underscore. [Toni]
- Density. [Toni]
- W2 works. [Toni]
- Lambda error. [Toni]
- Plot2. [Toni]
- Plots. [Toni]
- Step pattern by name. [Toni]
- Renamed internal modules. [Toni]
- Renaming. [Toni]
- Renaming. [Toni]
- Renaming package. [Toni]
- Markdown conversion. [Toni]
- Progress. [Toni]
- Docs in. [Toni]
- Added tags. [Toni]
- Inserting ok. [Toni]
- Checkpoint. [Toni]
- Abort. [Toni]
- Abort roxypick. [Toni]
- Headers. [Toni]
- Plot step pattern. [Toni]
- Countpaths. [Toni]
- Countpaths. [Toni]
- Mkdirdeltas. [Toni]
- Windowing. [Toni]
- Mvm, bt. [Toni]
- Object. [Toni]
- Progress. [Toni]
- All patterns ok. [Toni]
- Checkpoint. [Toni]
- Pattern building. [Toni]
- Listed step patterns. [Toni]
- Print and T. [Toni]
- Test ok. [Toni]
- Builds. [Toni]
- Checkpoint. [Toni]
- More import. [Toni]
- Initial import. [Toni]
- Initial commit. [Toni G]


